<?php

namespace Drupal\phpunit_tests;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Database\Connection;

/**
 * Phpunit Tests Services.
 */
class PhpunitTestsRepositoryService {

  /**
   * The database service.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * The time interface.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $timeInterface;

  /**
   * PhpunitTestsResourceService constructor.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection.
   * @param \Drupal\Component\Datetime\TimeInterface $timeInterface
   *   The load resource service.
   */
  public function __construct(
    Connection $connection,
    TimeInterface $timeInterface,
  ) {
    $this->connection = $connection;
    $this->timeInterface = $timeInterface;
  }

  /**
   * Creates a log entry.
   *
   * @param string $area
   *   The area the module is located. Core, contrib or custom.
   * @param string $module
   *   The module name.
   * @param string $directory
   *   The test directory. Unit, Functional etc.
   * @param string $test
   *   The absolute path the tests.
   * @param array $data
   *   The area where the module is. Core, contrib or custom.
   *
   * @return bool
   *   True or false depending on if insert succeeds.
   */
  public function createLog($area, $module, $directory, $test, $data) {
    $db1 = $this->connection->insert('phpunit_test')
      ->fields(
              [
                'created' => $this->timeInterface->getRequestTime(),
              ]
          )
      ->execute();

    $db2 = $this->connection->insert('phpunit_test_item')
      ->fields(
              [
                'phpunit_test_id' => $db1,
                'area' => $area,
                'module' => $module,
                'directory' => $directory,
                'test' => $test,
                'error_report' => $data,
              ]
          )
      ->execute();

    if ($db1 && $db2) {
      return TRUE;
    }
    else {
      return FALSE;
    }
  }

}
