<?php

namespace Drupal\testsuite;

use Drupal\Component\Utility\Xss;

/**
 * Test Suite Base Trait.
 */
trait BaseTrait {

  /**
   * The list of areas represent the areas where modules are.
   *
   * @var array
   */
  protected $areas = [
    'core',
    'contrib',
    'custom',
  ];

  /**
   * The list of directories represent the directories where phpunit tests are.
   *
   * @var array
   */
  protected $directories = [
    'Unit',
    'Kernel',
    'Functional',
    'FunctionalJavascript',
  ];

  /**
   * Formats the message.
   *
   * @param string $message
   *   The error report message.
   *
   * @return string|bool
   *   The message formated or FALSE.
   */
  protected function formatMessage($message) {
    if ($message != NULL) {
      $newMessage = str_replace("\n\n\n", "<br />", $message);
      $newMessage = str_replace("\n\n", "<br />", $newMessage);
      $newMessage = str_replace("\n", "<br />", $newMessage);
      return Xss::filterAdmin($newMessage);
    }
    else {
      return FALSE;
    }
  }

  /**
   * Takes the full file path and returns the file name.
   *
   * @param string $filePath
   *   The file we are reporting on.
   *
   * @return string
   *   The filename.
   */
  protected function getFileName($filePath) {
    if (preg_match('/\([^)]*\)/', $filePath)) {
      $fileParts = preg_split('/\s\(/', $filePath);
      $filePath = $fileParts[0];
    }
    $filePart = explode(DIRECTORY_SEPARATOR, $filePath);
    if (isset($fileParts[1])) {
      return end($filePart) . " (" . $fileParts[1];
    }
    else {
      return end($filePart);
    }

  }

  /**
   * Displays an Emoji representing results of a vulnerability check.
   *
   * @param int $ifVulnerability
   *   The type of emogi to display.
   *
   * @return markup
   *   Markup to be rendered.
   */
  protected function getEmoji($ifVulnerability) {
    switch ($ifVulnerability) {
      case 0:
        return '<span class="testsuite-vulnerability-emoji" title="No vulnerabilities">✔️</span>';

      case 1:
        return '<span class="testsuite-vulnerability-emoji" title="Vulnerabilities detected. Please go to the details page to view a vulnerability report.">❗</span>';

      case 2:
        return '<span class="testsuite-vulnerability-emoji" title="The checker relies on either a composer.json or package.json file for information on a package. A reliable vulnerability check could not be made.">❔</span>';

      default:
        return '<span class="testsuite-vulnerability-emoji" title="The version could not be identified through composer.json or package.json. There are vulnerabilities with a version or versions of this package. Please double check the version in the top of the css or js files and compare with the version specified in the vulnerability report. Without a specifing the version in the json file I cannot perfectly realize the version with this software.">❓</span>';
    }
  }

}
